@@ -119,7 +119,7 @@ class AboutWindow(Gtk.Window):
             gtk_ver = "GTK3"
 
         self.__lbl_title.set_markup("<b>MATE Dock Applet</b>")
-        self.__lbl_ver = Gtk.Label("V" + "0.89 (" + gtk_ver + ")")
+        self.__lbl_ver = Gtk.Label("V" + "20.04.0 (" + gtk_ver + ")")
         self.__lbl_blank2 = Gtk.Label()
 
         self.__tb_gpl = Gtk.TextBuffer()
